@@ -28,6 +28,17 @@ NULL
 #' @usage data(df_pop_county)
 NULL
 
+#' A data.frame containing population estimates for all Census Tracts in New York 
+#' State in 2012.   
+#'
+#' @name df_pop_ny_tract
+#' @docType data
+#' @references Taken from the US American Community Survey (ACS) 5 year estimates.
+#' 
+#' @keywords data
+#' @usage data(df_pop_ny_tract)
+NULL
+
 #' A data.frame containing election results from the 2012 US Presidential election.  
 #'
 #' @name df_president
@@ -68,7 +79,7 @@ NULL
 #' @usage data(df_state_age_2015)
 NULL
 
-#' A data.frame containing all US presdiential election results from 1789 to 2012
+#' A data.frame containing all US presidential election results from 1789 to 2012
 #' 
 #' Legend: 
 #' \itemize{
@@ -149,6 +160,16 @@ NULL
 #' }
 NULL
 
+#' A data.frame containing demographic statistics for each Census Tract in New York State.
+#' 
+#' @name df_ny_tract_demographics
+#' @docType data
+#' @references Data comes from the 2013 5-year American Community Survey (ACS). Data generated by
+#' ?get_tract_demographics. 
+#' @keywords data
+#' @usage data(df_ny_tract_demographics)
+NULL
+
 #' A vector of the names of US Continental US States.
 #'
 #' @name continental_us_states
